@@ -219,17 +219,18 @@ long file_read_ulong(char *file, const char *tag)
 
 int file_write_ulong(char *file, unsigned long val)
 {
-	FILE *f;
-	int ret;
+	int fd, ret, buflen;
+	char buf[20];
 
-	f = fopen(file, "w");
-	if (!f) {
+	fd = open(file, O_WRONLY);
+	if (fd < 0) {
 		ERROR("Couldn't open %s: %s\n", file, strerror(errno));
 		return -1;
 	}
 
-	ret = fprintf(f, "%lu", val);
-	fclose(f);
+	buflen = sprintf(buf, "%lu", val);
+	ret = write(fd, buf, buflen);
+	close(fd);
 	return ret > 0 ? 0 : -1;
 }
 
@@ -301,14 +302,14 @@ void hugetlbfs_setup_env()
 
 	env = getenv("HUGETLB_RESTRICT_EXE");
 	if (env) {
-		char *p, *tok, *exe, buf[MAX_EXE+1], restrict[MAX_EXE];
+		char *p, *tok, *exe, buf[MAX_EXE+1], restriction[MAX_EXE];
 		int found = 0;
 
 		exe = get_exe_name(buf, sizeof buf);
 		DEBUG("Found HUGETLB_RESTRICT_EXE, this exe is \"%s\"\n", exe);
-		strncpy(restrict, env, sizeof restrict);
-		restrict[sizeof(restrict)-1] = 0;
-		for (p = restrict; (tok = strtok(p, ":")) != NULL; p = NULL) {
+		strncpy(restriction, env, sizeof restriction);
+		restriction[sizeof(restriction)-1] = 0;
+		for (p = restriction; (tok = strtok(p, ":")) != NULL; p = NULL) {
 			DEBUG("  ...check exe match for \"%s\"\n",  tok);
 			if (strcmp(tok, exe) == 0) {
 				found = 1;
@@ -799,6 +800,27 @@ int hpool_sizes(struct hpage_pool *pools, int pcnt)
 	return (which < pcnt) ? which : -1;
 }
 
+int arch_has_slice_support(void)
+{
+#ifdef __powerpc64__
+	char mmu_type[16];
+	FILE *fp;
+
+	fp = popen("cat /proc/cpuinfo | grep MMU | awk '{ print $3}'", "r");
+	if (!fp || fscanf(fp, "%s", mmu_type) < 0) {
+		ERROR("Failed to determine MMU type\n");
+		abort();
+	}
+
+	pclose(fp);
+	return strcmp(mmu_type, "Hash") == 0;
+#elif defined(__powerpc__) && !defined(PPC_NO_SEGMENTS)
+	return 1;
+#else
+	return 0;
+#endif
+}
+
 /*
  * If we have a default page size then we support hugepages.
  */
@@ -1158,6 +1180,7 @@ long dump_proc_pid_maps()
 	FILE *f;
 	char line[MAPS_BUF_SZ];
 	size_t ret;
+	long result = -1;
 
 	f = fopen("/proc/self/maps", "r");
 	if (!f) {
@@ -1167,21 +1190,36 @@ long dump_proc_pid_maps()
 
 	while (1) {
 		ret = fread(line, sizeof(char), MAPS_BUF_SZ, f);
-		if (ret < 0) {
-			ERROR("Failed to read /proc/self/maps\n");
-			return -1;
-		}
-		if (ret == 0)
+		if (ret < MAPS_BUF_SZ) {
+			if (ferror(f)) {
+				ERROR("Failed to read /proc/self/maps\n");
+				goto out;
+			}
+
+			// else
 			break;
+		}
+
 		ret = fwrite(line, sizeof(char), ret, stderr);
-		if (ret < 0) {
-			ERROR("Failed to write /proc/self/maps to stderr\n");
-			return -1;
+		if (ret == 0) {
+			if (ferror(stderr)) {
+				ERROR("Failed to write /proc/self/maps to stderr\n");
+				goto out;
+			}
+			/*
+			 * feof should never happen to stderr, if it does there is nothing more we
+			 * can do so simply clean up and return
+			 */
+			ERROR("Cannot write /proc/self/maps because stderr reached EOF, "
+				"was it closed?\n");
+			goto out;
 		}
 	}
 
+	result = 0;
+out:
 	fclose(f);
-	return 0;
+	return result;
 }
 
 long read_meminfo(const char *tag)
